package Religion::Package;

use strict;
use vars qw($VERSION $linenum);
use Religion;


$VERSION = '0.01';


#######################################################
sub import
{
    ($linenum)=@_;
    
    $Die::Handler=DiePreHandler->new(\&_pretty_msg);
    $Warn::Handler=WarnPreHandler->new(\&_pretty_msg);
}

sub _pretty_msg
{
    my($message)=@_;
    my $q=0;
    return @_ if substr($message, -1) eq "\n";
    my $caller=(caller(2))[0];
    $caller.='('.(caller(2))[2].')' if $linenum;
    return @_ if $caller eq 'main';
    $_[0]="$caller $_[0]\n";
    $_[1]=$_[0];
    return @_;
}


1;
__END__
# Below is the stub of documentation for your module. You better edit it!

=head1 NAME

Religion::Package - Prepend package name to warn/die messages

=head1 SYNOPSIS

    use Religion::Package;
    # now all warn/die message have Package::Name in front, rather then
    # "at $file line ###\n" appended

    use Religion::Package qw(1);
    # now all warn/die message have Package:Name(line-num) in front, rather then
    # "at $file line ###\n" appended

=head1 DESCRIPTION

Tired of extremly long warning messages that tell just clog log files? 
Annoyed at the fact that C<warn "My message\n";>, while less verbose, also
doesn't help you trace down the warning?  Bored of typing 
C<warn __PACKAGE__, " My message\n">?

LOOK NO FURTHER!

C<Religion::Package> cures all your ills!  Include it once in your program,
and your life will be changed FOR EVER!  It even respects Current Standards
(cf \n on the end and the message isn't changed).

Compatible with eval!  Leaves package main alone!  Interfaces with Religion!

=head1 AUTHOR

Philip Gwyn <perl@pied.nu>

=head1 SEE ALSO

Religion.

=cut
